package io.renren.modules.app.dao;

import java.util.List;

import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;

import com.baomidou.mybatisplus.mapper.BaseMapper;

import io.renren.modules.app.entity.HPzEntity2;
import io.renren.modules.app.entity.RjzEntity;

/**
 * 日记账
 *
 * @author lj
 * @email 3499722281@qq.com
 * @date 2019-05-09 09:49:15
 */
@Mapper
public interface RjzDao extends BaseMapper<RjzEntity> {
	// 日记账查询
	List<RjzEntity> rjzSelect_1(RjzEntity rjzEntity);

	// 日记账查询
	List<RjzEntity> rjzSelect_2(RjzEntity rjzEntity);
	
	//查询kmmc
	String select_kmmc(@Param("ztbm") String ztbm,@Param("kmdm") String kmdm,@Param("len") int len);
	
	//返回kmjb
	String select_kmjb(@Param("ztbm") String ztbm);
	
	String select_kmjb2(@Param("kmjb") String kmjb,@Param("len3") String len3);
	List<HPzEntity2> select_pz(HPzEntity2 rjzEntity2);
	
	List<HPzEntity2> select_pz1(HPzEntity2 rjzEntity2);
	
	List<HPzEntity2> select_pz2(HPzEntity2 rjzEntity2);
	
	List<HPzEntity2> select_pz3(HPzEntity2 rjzEntity2);
	
	List<HPzEntity2> select_pz4(HPzEntity2 rjzEntity2);
}
